gedidb.granule\_handler
=======================

.. currentmodule:: gedidb

.. autoclass:: granule_handler

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~granule_handler.__init__
      ~granule_handler.beam
      ~granule_handler.build_virtual_dataset
      ~granule_handler.clear
      ~granule_handler.close
      ~granule_handler.copy
      ~granule_handler.create_dataset
      ~granule_handler.create_dataset_like
      ~granule_handler.create_group
      ~granule_handler.create_virtual_dataset
      ~granule_handler.flush
      ~granule_handler.get
      ~granule_handler.items
      ~granule_handler.iter_beams
      ~granule_handler.keys
      ~granule_handler.list_beams
      ~granule_handler.move
      ~granule_handler.pop
      ~granule_handler.popitem
      ~granule_handler.require_dataset
      ~granule_handler.require_group
      ~granule_handler.setdefault
      ~granule_handler.update
      ~granule_handler.values
      ~granule_handler.visit
      ~granule_handler.visit_links
      ~granule_handler.visititems
      ~granule_handler.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~granule_handler.abstract
      ~granule_handler.attrs
      ~granule_handler.driver
      ~granule_handler.file
      ~granule_handler.filename
      ~granule_handler.filename_metadata
      ~granule_handler.id
      ~granule_handler.libver
      ~granule_handler.meta_block_size
      ~granule_handler.mode
      ~granule_handler.n_beams
      ~granule_handler.name
      ~granule_handler.parent
      ~granule_handler.product
      ~granule_handler.ref
      ~granule_handler.regionref
      ~granule_handler.start_datetime
      ~granule_handler.swmr_mode
      ~granule_handler.userblock_size
      ~granule_handler.uuid
      ~granule_handler.version_granule
      ~granule_handler.version_product
   
   